HTTP Layer
==========

Low-level HTTP transport with rate limiting and retry logic.

HttpClient
----------

.. autoclass:: etoropy.HttpClient
   :members:
   :show-inheritance:

RequestOptions
--------------

.. autoclass:: etoropy.RequestOptions
   :members:

RateLimiter
-----------

.. autoclass:: etoropy.RateLimiter
   :members:
   :show-inheritance:

RateLimiterOptions
------------------

.. autoclass:: etoropy.RateLimiterOptions
   :members:

RetryOptions
------------

.. autoclass:: etoropy.http.RetryOptions
   :members:
